@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 
 import unittest
+import imp
 import os
 import re
 
@@ -10,14 +11,24 @@ except ImportError:
     coverage = None
 
 try:
-    import expecter
-    import mock
+    for m in ('expecter', 'mock'):
+        imp.find_module(m)
 except ImportError as ie:
     print('Please install the test dependencies as documented in the README')
-    raise ie
+    raise
 
 TEST_DIR = 'tests'
 
+
+def collect_tests():
+    # list files in directory tests/
+    names = os.listdir(TEST_DIR)
+    regex = re.compile("(?!_+)\w+\.py$")
+    join = '.'.join
+    # Make a list of the names like 'tests.test_name'
+    names = [join([TEST_DIR, f[:-3]]) for f in names if regex.match(f)]
+    return unittest.defaultTestLoader.loadTestsFromNames(names)
+
 if __name__ == "__main__":
     if coverage:
         cov = coverage.coverage(source=['github3'],
@@ -26,13 +37,7 @@ if __name__ == "__main__":
         cov.exclude('def __repr__')
         cov.start()
 
-    # list files in directory tests/
-    names = os.listdir(TEST_DIR)
-    regex = re.compile("(?!_+)\w+\.py$")
-    join = '.'.join
-    # Make a list of the names like 'tests.test_name'
-    names = [join([TEST_DIR, f[:-3]]) for f in names if regex.match(f)]
-    suite = unittest.defaultTestLoader.loadTestsFromNames(names)
+    suite = collect_tests()
     unittest.TextTestRunner(verbosity=1).run(suite)
 
     if coverage:
